==> get-1.9.25-alpha.tar.gz: lib/src/routes/utils/parse_arguments.dart <==
import 'package:flutter/material.dart';

class ParseRoute {
  // private
  final List<ParseRouterouteSplit> _routeSplits = <ParseRouterouteSplit>[];
  bool _hasDefaultRoute = false;

  void addRoute(String routePath) {
    print("add route chaamdo");
    String path = routePath;

    if (path == Navigator.defaultRouteName) {
      if (_hasDefaultRoute) {
        throw ("Default route was already defined");
      }
      var routeSplit =
          ParseRouterouteSplit(path, ParseRouterouteSplitType.component);
      routeSplit.routes = [routePath];
      _routeSplits.add(routeSplit);
      _hasDefaultRoute = true;
      return;
    }
    if (path.startsWith("/")) {
      path = path.substring(1);
    }
    List<String> pathComponents = path.split('/');
    ParseRouterouteSplit parent;
    for (int i = 0; i < pathComponents.length; i++) {
      String component = pathComponents[i];
      ParseRouterouteSplit routeSplit =
          _routeSplitForComponent(component, parent);
      if (routeSplit == null) {
        ParseRouterouteSplitType type = _typeForComponent(component);
        routeSplit = ParseRouterouteSplit(component, type);
        routeSplit.parent = parent;
        if (parent == null) {
          _routeSplits.add(routeSplit);
        } else {
          parent.routeSplits.add(routeSplit);
        }
      }
      if (i == pathComponents.length - 1) {
        if (routeSplit.routes == null) {
          routeSplit.routes = [routePath];
        } else {
          routeSplit.routes.add(routePath);
        }
      }
      parent = routeSplit;
    }
  }

  AppRouteMatch split(String path) {
    String usePath = path;
    if (usePath.startsWith("/")) {
      usePath = path.substring(1);
    }
    List<String> components = usePath.split("/");
    if (path == Navigator.defaultRouteName) {
      components = ["/"];
    }

    Map<ParseRouterouteSplit, ParseRouterouteSplitMatch> routeSplitMatches =
        <ParseRouterouteSplit, ParseRouterouteSplitMatch>{};
    List<ParseRouterouteSplit> routeSplitsToCheck = _routeSplits;
    for (String checkComponent in components) {
      Map<ParseRouterouteSplit, ParseRouterouteSplitMatch> currentMatches =
          <ParseRouterouteSplit, ParseRouterouteSplitMatch>{};
      List<ParseRouterouteSplit> nextrouteSplits = <ParseRouterouteSplit>[];
      for (ParseRouterouteSplit routeSplit in routeSplitsToCheck) {
        String pathPart = checkComponent;
        Map<String, String> queryMap;
        if (checkComponent.contains("?") && !checkComponent.contains("=")) {
          var splitParam = checkComponent.split("?");
          pathPart = splitParam[0];
          queryMap = {pathPart: splitParam[1]};
          print(queryMap.toString());
        } else if (checkComponent.contains("?")) {
          var splitParam = checkComponent.split("?");
          var splitParam2 = splitParam[1].split("=");
          if (!splitParam2[1].contains("&")) {
            pathPart = splitParam[0];
            queryMap = {splitParam2[0]: splitParam2[1]};
          } else {
            pathPart = splitParam[0];
            final segunda = splitParam[1];
            var secondParameter = segunda.split("=");
            var segundoSplit = splitParam2[1].split("&");
            print(" CUUUUU ${segundoSplit[0]}");
            queryMap = {secondParameter[0]: segundoSplit[0]};
            var xsplitParam = checkComponent.split("&");
            var xsplitParam2 = xsplitParam[1].split("=");
            queryMap.addAll({xsplitParam2[0]: xsplitParam2[1]});
          }
          print(queryMap.toString());
        }
        bool isMatch =
            (routeSplit.part == pathPart || routeSplit.isParameter());
        if (isMatch) {
          ParseRouterouteSplitMatch parentMatch =
              routeSplitMatches[routeSplit.parent];
          ParseRouterouteSplitMatch match =
              ParseRouterouteSplitMatch.fromMatch(parentMatch, routeSplit);
          if (routeSplit.isParameter()) {
            String paramKey = routeSplit.part.substring(1);
            match.parameters[paramKey] = pathPart;
          }
          if (queryMap != null) {
            match.parameters.addAll(queryMap);
          }

          currentMatches[routeSplit] = match;
          if (routeSplit.routeSplits != null) {
            nextrouteSplits.addAll(routeSplit.routeSplits);
          }
        }
      }
      routeSplitMatches = currentMatches;
      routeSplitsToCheck = nextrouteSplits;
      if (currentMatches.values.length == 0) {
        return null;
      }
    }
    List<ParseRouterouteSplitMatch> matches = routeSplitMatches.values.toList();
    if (matches.length > 0) {
      ParseRouterouteSplitMatch match = matches.first;
      ParseRouterouteSplit routeSplitToUse = match.routeSplit;
      // print(
      //     "using match: ${routeSplitToUse?.parent?.part}, ${routeSplitToUse?.part}, ${match?.parameters}");
      if (routeSplitToUse != null &&
          routeSplitToUse.routes != null &&
          routeSplitToUse.routes.length > 0) {
        AppRouteMatch routeMatch = AppRouteMatch();
        routeMatch.parameters = match.parameters;
        if (routeSplitToUse.isParameter()) {
          routeMatch.route = match.routeSplit.parent.part;
        } else {
          routeMatch.route = match.routeSplit.part;
        }

        return routeMatch;
      }
    }
    return null;
  }

  ParseRouterouteSplit _routeSplitForComponent(
      String component, ParseRouterouteSplit parent) {
    List<ParseRouterouteSplit> routeSplits = _routeSplits;
    if (parent != null) {
      routeSplits = parent.routeSplits;
    }
    for (ParseRouterouteSplit routeSplit in routeSplits) {
      if (routeSplit.part == component) {
        return routeSplit;
      }
    }
    return null;
  }

  ParseRouterouteSplitType _typeForComponent(String component) {
    ParseRouterouteSplitType type = ParseRouterouteSplitType.component;
    if (_isParameterComponent(component)) {
      type = ParseRouterouteSplitType.parameter;
    }
    return type;
  }

  /// Is the path component a parameter
  bool _isParameterComponent(String component) {
    return component.startsWith(":");
  }
}

enum ParseRouterouteSplitType {
  component,
  parameter,
}

class AppRouteMatch {
  Map<String, String> parameters = <String, String>{};
  String route = '/';
}

class ParseRouterouteSplitMatch {
  ParseRouterouteSplitMatch(this.routeSplit);

  ParseRouterouteSplitMatch.fromMatch(
      ParseRouterouteSplitMatch match, this.routeSplit) {
    parameters = <String, String>{};
    if (match != null) {
      parameters.addAll(match.parameters);
    }
  }

  ParseRouterouteSplit routeSplit;
  Map<String, String> parameters = <String, String>{};
}

class ParseRouterouteSplit {
  // constructors
  ParseRouterouteSplit(this.part, this.type);

  // properties
  String part;
  ParseRouterouteSplitType type;
  List<String> routes = [];
  List<ParseRouterouteSplit> routeSplits = <ParseRouterouteSplit>[];
  ParseRouterouteSplit parent;

  bool isParameter() {
    return type == ParseRouterouteSplitType.parameter;
  }
}

==> get-1.9.30-alpha.tar.gz: lib/src/routes/utils/parse_arguments.dart <==
import 'package:flutter/material.dart';

class ParseRoute {
  // private
  final List<ParseRouterouteSplit> _routeSplits = <ParseRouterouteSplit>[];
  // bool _hasDefaultRoute = false;

  void addRoute(String routePath) {
    print("add route chaamdo");
    String path = routePath;

    if (path == Navigator.defaultRouteName) {
      // if (_hasDefaultRoute) {
      //   throw ("Default route was already defined");
      // }
      var routeSplit =
          ParseRouterouteSplit(path, ParseRouterouteSplitType.component);
      routeSplit.routes = [routePath];
      _routeSplits.add(routeSplit);
      // _hasDefaultRoute = true;
      return;
    }
    if (path.startsWith("/")) {
      path = path.substring(1);
    }
    List<String> pathComponents = path.split('/');
    ParseRouterouteSplit parent;
    for (int i = 0; i < pathComponents.length; i++) {
      String component = pathComponents[i];
      ParseRouterouteSplit routeSplit =
          _routeSplitForComponent(component, parent);
      if (routeSplit == null) {
        ParseRouterouteSplitType type = _typeForComponent(component);
        routeSplit = ParseRouterouteSplit(component, type);
        routeSplit.parent = parent;
        if (parent == null) {
          _routeSplits.add(routeSplit);
        } else {
          parent.routeSplits.add(routeSplit);
        }
      }
      if (i == pathComponents.length - 1) {
        if (routeSplit.routes == null) {
          routeSplit.routes = [routePath];
        } else {
          routeSplit.routes.add(routePath);
        }
      }
      parent = routeSplit;
    }
  }

  AppRouteMatch split(String path) {
    String usePath = path;
    if (usePath.startsWith("/")) {
      usePath = path.substring(1);
    }
    List<String> components = usePath.split("/");
    if (path == Navigator.defaultRouteName) {
      components = ["/"];
    }

    Map<ParseRouterouteSplit, ParseRouterouteSplitMatch> routeSplitMatches =
        <ParseRouterouteSplit, ParseRouterouteSplitMatch>{};
    List<ParseRouterouteSplit> routeSplitsToCheck = _routeSplits;
    for (String checkComponent in components) {
      Map<ParseRouterouteSplit, ParseRouterouteSplitMatch> currentMatches =
          <ParseRouterouteSplit, ParseRouterouteSplitMatch>{};
      List<ParseRouterouteSplit> nextrouteSplits = <ParseRouterouteSplit>[];
      for (ParseRouterouteSplit routeSplit in routeSplitsToCheck) {
        String pathPart = checkComponent;
        Map<String, String> queryMap;
        if (checkComponent.contains("?") && !checkComponent.contains("=")) {
          var splitParam = checkComponent.split("?");
          pathPart = splitParam[0];
          queryMap = {pathPart: splitParam[1]};
          print(queryMap.toString());
        } else if (checkComponent.contains("?")) {
          var splitParam = checkComponent.split("?");
          var splitParam2 = splitParam[1].split("=");
          if (!splitParam2[1].contains("&")) {
            pathPart = splitParam[0];
            queryMap = {splitParam2[0]: splitParam2[1]};
          } else {
            pathPart = splitParam[0];
            final segunda = splitParam[1];
            var secondParameter = segunda.split("=");
            var segundoSplit = splitParam2[1].split("&");
            print(" CUUUUU ${segundoSplit[0]}");
            queryMap = {secondParameter[0]: segundoSplit[0]};
            var xsplitParam = checkComponent.split("&");
            var xsplitParam2 = xsplitParam[1].split("=");
            queryMap.addAll({xsplitParam2[0]: xsplitParam2[1]});
          }
          print(queryMap.toString());
        }
        bool isMatch =
            (routeSplit.part == pathPart || routeSplit.isParameter());
        if (isMatch) {
          ParseRouterouteSplitMatch parentMatch =
              routeSplitMatches[routeSplit.parent];
          ParseRouterouteSplitMatch match =
              ParseRouterouteSplitMatch.fromMatch(parentMatch, routeSplit);
          if (routeSplit.isParameter()) {
            String paramKey = routeSplit.part.substring(1);
            match.parameters[paramKey] = pathPart;
          }
          if (queryMap != null) {
            match.parameters.addAll(queryMap);
          }

          currentMatches[routeSplit] = match;
          if (routeSplit.routeSplits != null) {
            nextrouteSplits.addAll(routeSplit.routeSplits);
          }
        }
      }
      routeSplitMatches = currentMatches;
      routeSplitsToCheck = nextrouteSplits;
      if (currentMatches.values.length == 0) {
        return null;
      }
    }
    List<ParseRouterouteSplitMatch> matches = routeSplitMatches.values.toList();
    if (matches.length > 0) {
      ParseRouterouteSplitMatch match = matches.first;
      ParseRouterouteSplit routeSplitToUse = match.routeSplit;
      // print(
      //     "using match: ${routeSplitToUse?.parent?.part}, ${routeSplitToUse?.part}, ${match?.parameters}");
      if (routeSplitToUse != null &&
          routeSplitToUse.routes != null &&
          routeSplitToUse.routes.length > 0) {
        AppRouteMatch routeMatch = AppRouteMatch();
        routeMatch.parameters = match.parameters;
        if (routeSplitToUse.isParameter()) {
          routeMatch.route = match.routeSplit.parent.part;
        } else {
          routeMatch.route = match.routeSplit.part;
        }

        return routeMatch;
      }
    }
    return null;
  }

  ParseRouterouteSplit _routeSplitForComponent(
      String component, ParseRouterouteSplit parent) {
    List<ParseRouterouteSplit> routeSplits = _routeSplits;
    if (parent != null) {
      routeSplits = parent.routeSplits;
    }
    for (ParseRouterouteSplit routeSplit in routeSplits) {
      if (routeSplit.part == component) {
        return routeSplit;
      }
    }
    return null;
  }

  ParseRouterouteSplitType _typeForComponent(String component) {
    ParseRouterouteSplitType type = ParseRouterouteSplitType.component;
    if (_isParameterComponent(component)) {
      type = ParseRouterouteSplitType.parameter;
    }
    return type;
  }

  /// Is the path component a parameter
  bool _isParameterComponent(String component) {
    return component.startsWith(":");
  }
}

enum ParseRouterouteSplitType {
  component,
  parameter,
}

class AppRouteMatch {
  Map<String, String> parameters = <String, String>{};
  String route = '/';
}

class ParseRouterouteSplitMatch {
  ParseRouterouteSplitMatch(this.routeSplit);

  ParseRouterouteSplitMatch.fromMatch(
      ParseRouterouteSplitMatch match, this.routeSplit) {
    parameters = <String, String>{};
    if (match != null) {
      parameters.addAll(match.parameters);
    }
  }

  ParseRouterouteSplit routeSplit;
  Map<String, String> parameters = <String, String>{};
}

class ParseRouterouteSplit {
  // constructors
  ParseRouterouteSplit(this.part, this.type);

  // properties
  String part;
  ParseRouterouteSplitType type;
  List<String> routes = [];
  List<ParseRouterouteSplit> routeSplits = <ParseRouterouteSplit>[];
  ParseRouterouteSplit parent;

  bool isParameter() {
    return type == ParseRouterouteSplitType.parameter;
  }
}
